/* ********************************************************************* */
/*    Filename: CHAMBERS.INC            #include file of declarations    */
/*                  Assorted Objects, FXs, and Textures                  */
/*             for use in Chambers, Path & GrillBox scenes               */
/* Michael Brendan Hurley                           AUG-OCT 96  Ver. 1.0 */
/*                                                  NOV-DEC 96  Ver. 2.0 */
/* revised GrillBox elements, new Building & Statues    DEC 96  Ver. 2.1 */
/* ********************************************************************* */
/* ********************************************************************* */

#include "colors.inc"                  // standard colors
#include "shapes.inc"                  // standard shapes
#include "textures.inc"                // standard textures

/* ********************************************************************* */
//            DEFINE Spot Lights on Specific Objects                     //
/* ********************************************************************* */

// DEFINE  Flood Lights   *****   *****

#declare FloodSE1 =
light_source { < 2000 500 -2000 >
               color White
             }  //end light Flood SE 1

#declare FloodSE2 =
light_source { < 750  700 -1000 >
               color White
             }  //end of SE 2

#declare FloodSW1 =
light_source { < -870 870 -870 >
               color White
             }  //end light Flood SW 1

#declare FloodSW2 =
light_source { < -1000 750 -1100 >
               color White
             }  //end light Flood SW 2

#declare FloodNE1 =
light_source { < 1400 1500 1100 >
               color White
             }  //end of NE 1

#declare FloodNW1 =
light_source { < -1200 1500 1000 >
               color White
             }  //end of NW 1

/* ********************************************************************* */
//                           Texture Definitions                         //
/* ********************************************************************* */

// DECLARE TEXTURE ***** Green surface with lavendar cloud pattern

#declare Green_World =
texture { wood
          turbulence 1.25
          color_map {
             [0.0  0.6  color LimeGreen  color ForestGreen]
             [0.1  0.6  color Yellow     color LimeGreen]
             [0.6  1.0  color LimeGreen  color Clear]
                    }  //end color map
          scale < 3.5 1.0 1.0 >
          diffuse 0.55
          brilliance 0.2
          reflection 0.2
        }  //end texture  Green World

/* ********************************************************************* */

// DEFINE  Ckeckered-Floors Sky TEXTURE   *****   *****

#declare Sky_Agate =
texture { agate
          color_map {
          // transparent fades to
          [0.0  0.95  color red 0.0  green 0.0  blue 0.9  alpha 1.0
                      color red 0.0  green 0.0  blue 0.8  alpha 1.0]
          // less deep blue to lighter blue
          [0.95 1.0   color red 0.5  green 0.0  blue 0.7  alpha 0.5
                      color red 0.5  green 0.5  blue 0.9]
                    }  //end color map
        }  // end texture Sky Agate

/* ********************************************************************* */

#declare Sky_Agate2 =
texture { agate
          color_map {
          // transparent fades to
          [0.0  0.99  color red 0.9  green 0.0  blue 0.0  alpha 1.0
                      color red 0.8  green 0.0  blue 0.0  alpha 1.0]
          // light red to deeper blue
          [0.99 1.0   color red 0.6  green 0.0  blue 0.6  alpha 0.5
                      color red 0.8  green 0.3  blue 0.3]
                    }  //end color map
        }  // end texture Sky Agate 2

/* ********************************************************************* */

// DEFINE A Variant of Jade for Tree Foliage   *****

#declare TreeJade =
texture {
   0.06
   marble
   color_map {
      [0.0  0.2   color red 0.1  green 0.8  blue 0.1
                  color red 0.0  green 0.4  blue 0.0 ]
      [0.2  0.5   color red 0.1  green 0.7  blue 0.1
                  color red 0.0  green 0.3  blue 0.0 ]
      [0.5  0.85  color red 0.1  green 0.6  blue 0.1
                  color red 0.0  green 0.3  blue 0.0 ]
      [0.85 1.0   color red 0.1  green 0.6  blue 0.1 alpha 0.6
                  color red 0.0  green 0.2  blue 0.0 alpha 0.6]
             } // end color map
   turbulence 19
   reflection 0.1
   diffuse    0.1
   brilliance 0.001
   scale < 2.5 3.0 1.5 >
        } // end texture Tree Jade

/* ********************************************************************* */

//DEFINE  a shiny black texture        ***** from Ttexture.INC

#declare Iris =
texture {
   color Black
   ambient 0.05
   diffuse 0.55
   phong 1.0
   phong_size 1000
   specular 1.0
   roughness 0.004
   reflection 0.75
        } // end texture Iris

/* ********************************************************************* */

// DEFINE  Glass TEXTURE

#declare Glass_1 =
   texture { color red 1 green 1 blue 1 alpha 0.9
             ambient 0.01
             diffuse 0.0
             reflection 0.512
             refraction 1.0
             ior 1.45
             specular 1.0
             roughness 0.001
           }  //end texture Glass_1

/* ********************************************************************* */
//                            Object Definitions                         //
/* ********************************************************************* */

#declare Center_Pole =
object {                            // A pillar at <0 0 0>
  intersection { Disk_Y }
                 texture { Green_World      // Stone2
                           turbulence 0.0   // Mix colors
                           rotate < 33 0 0 >// tilt texture on
                           rotate < 0 15 0 >//   the object
                         } // end texture
                 scale < 5 20 5 >           // Enlarge entire obj
                 color PaleGreen            // Low res. color
          } // end obj CenterPole

/* ********************************************************************* */

#declare LampPost_1 =                  // lamp globe on pillar
composite {
   object {                                 // sphere as light source
      union {
         sphere { < 0 0 0 > 1 } // end sphere
         light_source {
            < 0 0 0 >
            color Yellow
                      } // end light source
            } // end union sphere/light
      texture { color Yellow ambient 1 diffuse 0 }
      translate < 0 5 0 >
            } // end obj union lamp
   object {                                 // column
      Pillar_A
        texture { Blue_Agate
                    scale < 2 1 1 >
                    rotate < 45 0 0 >
                } // end texture
            scale < 0.35 1.15 0.35 >
            color Blue
          } //end obj 2
   object { Planet_Blank                    // sphere as pedistal
            texture { Jade }
            scale < 1.15 1.15 1.15 >
            color Green
          } //end obj 3
   bounded_by { intersection {              // bounding
                   Disk_Y
                   scale < 3.1 12.1 3.1 > }
              } // end bounding
          } // end composite LampPost_1

/* ********************************************************************* */

#declare LampPost_2 =                  // from LP_1 31 Mar 97
composite {
   object { Planet_Mirror              // Pedistal
            texture { Gold_Metal
                      reflection 1.0 }
            scale < 2 2 2 >
            color OldGold
          } //end obj 1
   object { Pillar_A                   // Column
            texture { Blood_Marble
                      scale < 2 4 1 >
                      rotate < 55 0 0 >
                    } // end texture
            scale < 0.85 2 0.85 >
            color Blue
          } //end obj 2
   object { Planet_Mirror               // Capital
            texture { Gold_Metal
                      reflection 1.0 }
            scale < 1.5 1.5 1.5 >
            translate < 0 10 0 >
            color OldGold
          } //end obj 3
   bounded_by { intersection {
                   Disk_Y
                   scale < 2.1 12.1 2.1 > }
              } // end bounding
          } // end composite LampPost 2

/* ********************************************************************* */
/* ********************************************************************* */

// Piriform: Looks like a hersheys kiss.

#declare Piriform =
quartic {
   < 4.0   0.0   0.0   -4.0  0.0   0.0   0.0   0.0   0.0  0.0
     0.0   0.0   0.0    0.0  0.0   0.0   0.0   0.0   0.0  0.0
     0.0   0.0   0.0    0.0  0.0   1.0   0.0   0.0   0.0  0.0
     0.0   0.0   1.0    0.0  0.0 >
        }  // end quartic

/* ********************************************************************* */

#declare Tree_B =
composite {
   object {
      quartic { Piriform               // foliage
                texture { TreeJade     // modified Jade
                        } // end texture
                scale < 12.5 6.5 6.5 >
                rotate < 0 90 0 >
                rotate < -90 0 0 >
                translate < 0 16 0 >
                color ForestGreen
              } // end Piri
          } // end obj Piriform
   object { Center_Pole                // trunk
              texture { DMFWood5 }
              scale < 0.17 0.6 0.17 >
          }  // end obj Pole
   bounded_by { intersection {
                   Disk_Y
                   scale < 5 17 5 > }
              } // end bounding
          }  // end composite  Tree

/* ********************************************************************* */

#declare Row_Of_Trees =                // runs due east from 0 0 0
composite {
   composite { Tree_B  translate < 0 0 0 > }
   composite { Tree_B  translate < 0 0 10 > }
   composite { Tree_B  translate < 0 0 20 > }
   composite { Tree_B  translate < 0 0 30 > }
          }  // end composite Row of Trees

/* ********************************************************************* */

// DEFINE  Grove of Trees  OBJECT   *****   ******

#declare Grove_B =                     // a grouping of Trees
composite {
   composite { Tree_B  scale < 1.0 1.0 1.0 >  translate <   0  0.0   0 > }
   composite { Tree_B  scale < 1.1 1.2 1.1 >  translate <   5  0.0   5 > }
   composite { Tree_B  scale < 0.7 0.8 0.7 >  translate <  -6  0.0   9 > }
   composite { Tree_B  scale < 1.2 1.2 1.2 >  translate <  -9  0.0  -5 > }
   composite { Tree_B  scale < 0.5 0.9 0.5 >  translate < -12  0.1   4 > }
   composite { Tree_B  scale < 0.6 1.5 0.6 >  translate <   1  0.0  -5 > }
   composite { Tree_B  scale < 0.7 1.0 0.7 >  translate <   7  0.0  -8 > }
   composite { Tree_B  scale < 0.8 0.8 0.8 >  translate <  15  0.0 -13 > }
   composite { Tree_B  scale < 1.1 0.0 1.1 >  translate <   2  0.0 -17 > }
          }  //end composite Grove B

/* ********************************************************************* */
/* ********************************************************************* */

// DECLARE Piriform with array of glass rods

#declare Piri_Glass_B =
composite {
   object { quartic {                  // 1st object in composite
               Piriform
               texture { Blue_Sky2
                         scale < 4 2 1 >
                       }  //end texture
               scale < 6.1 10 6.1 >
               rotate < 90 0 0 >
               rotate < 0 0 90 >
               translate < 0 8 0 >
               color ForestGreen
                    }  //end of quartic
          }  //end of object PiriForm
   object { intersection { Disk_Y }    // 2nd obj in comp
            texture { Glass
                      brilliance 0.5
                    }  //end texture
            scale < 0.5 20 0.5 >
            translate < -2 0 -2 >
            color Yellow
          }  //end obj Pillar
   object { intersection { Disk_Y }    // 3rd obj in comp
            texture { Glass
                      brilliance 0.5
                    }  //end texture
            scale < 0.5 15 0.5 >
            rotate < 0 0 75 >
            translate < 0 11 0 >
            color Yellow
          }  //end obj Pillar
   object { intersection { Disk_Y }    // 4th obj in comp
            texture { Glass
                      brilliance 0.5
                    }  //end texture
            scale < 0.75 10 0.75 >
            rotate < 50 0 0 >
            rotate < 0 45 0 >
            translate < 3 2 1 >
            color Yellow
          }  //end obj Pillar
   object { intersection { Disk_Y }    // 5th obj in comp
            texture { Glass
                      brilliance 0.5
                    }  //end texture
            scale < 0.5 10 0.5 >
            rotate < -35 0 0 >
            rotate < 0 0 -25 >
            translate < 0 8 0 >
            color Yellow
          }  //end obj Pillar
   object { intersection { Disk_Y }    // 6th obj in comp
            texture { Glass
                      brilliance 0.5
                    }  //end texture
            scale < 0.6 13 0.6 >
            rotate < 66 0 0 >
            translate < 5 5 5 >
            color Yellow
          }  //end obj Pillar
   bounded_by { intersection {
                  Disk_Y
                  scale < 10 15 10 >
                             } //end intersect
              }  // end bounding shape
          }  //end composite Piri_Glass B

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE  A Hedge   *****   from POOL.POV   *****

#declare Hedge_B =
object {                               // a cube textured like foliage
   intersection { Cube }
   scale < 5 1 1 >
   texture {
      0.05                                  // This dithers the colours
      color YellowGreen
      turbulence 0.7
      spotted 0.5
      colour_map {
         [0.00 0.25  colour YellowGreen colour Green ]
         [0.25 0.75  colour Green       colour DarkGreen]
         [0.75 1.001 colour DarkGreen   colour YellowGreen ]
           } // end color map
      wrinkles 1.0
      frequency 2000.0
      scale < 10.0 10.0 20.0 >
           } // end texture
   color YellowGreen
       }  // end object Hedge_B

/* ********************************************************************* */

#declare Road2 =                       // long thin plank
   object { Box_Plain texture { Dark_Wood }
                      scale < 2.5 0.1 100 >
          } // end Obj  Road 2

/* ********************************************************************* */
/* ********************************************************************* */

#declare Arch_B =                      // a basic arch from ROMAN.POV
object {                               // revised 18 Oct 96
   intersection {
      quadric { Cylinder_X scale < 1 10 10 > }
      quadric { Cylinder_X scale < 1  8  8 > inverse }
      plane { <1.0 0.0 0.0> 2.0 }
      plane { <-1.0 0.0 0.0> 2.0 }
      plane { <0.0 -1.0 0.0> 0.0 }
                 } //end intersection
   texture {
      Red_Marble
      scale < 5.0 2.5 5.0>
      ambient 0.2
      diffuse 0.5
      reflection 0.3
           } // end texture
   bounded_by { quadric {
                   Ellipsoid
                   scale < 5.8 13.8 13.8 >
                        } //end quartic
              } //end bounding
   color LightBlue
       } // end object Arch_B

/* ********************************************************************* */

#declare Arch_C =                      // Arch B revised again 18 Oct 96
object {
   intersection {
      quadric { Cylinder_X scale < 1 1.2 1.2 > }
      quadric { Cylinder_X scale < 1 1 1 > inverse }
      plane { <  1.0  0.0  0.0 > 2.0 }
      plane { < -1.0  0.0  0.0 > 2.0 }
      plane { <  0.0 -1.0  0.0 > 0.0 }
                 } //end intersection
   bounded_by {
      box { UnitBox
            scale < 1.3 2.3 2.3 > }
              } //end bounding
   texture {                           // changed from Arch B
      Red_Marble
      scale < 5 2.5 5 >
      ambient 0.2
      diffuse 0.5
      reflection 0.3
           } // end texture
   color LightBlue
       } // end object Arch_C

/* ********************************************************************* */

#declare Arch_Plain =                  // Arch C revised 11 Dec 96
object {
   intersection {
      quadric { Cylinder_X scale < 1 1 1 > }
      quadric { Cylinder_X scale < 0.75 0.75 0.75 > inverse }
      plane { <  5.0  0.0  0.0 > 1.0 }
      plane { < -5.0  0.0  0.0 > 1.0 }
      plane { <  0.0 -1.0  0.0 > 0.0 }
                 } //end intersection
   color Coral
       } // end object Arch_Plain

/* ********************************************************************* */

#declare Medallion =                   // a disk
object { intersection { Disk_X
                        scale < 0.25 1.5 1.5 > }
         texture {
            Red_Marble
            scale < 2 3 2 >
            ambient 0.2
            diffuse 0.5
            reflection 0.3
                 } // end texture
         color Red
       } // end obj Disk X Medallion

/* ********************************************************************* */

#declare Bar1 =                        // a thin bar
object { box {
            UnitBox
            scale < 0.2 0.2 1 > }
         texture {
            Red_Marble
            scale < 2 3 2 >
            ambient 0.2
            diffuse 0.5
            reflection 0.3
                 } // end texture
         color SpringGreen
       }  // end obj Bar 1

/* ********************************************************************* */

#declare Bar2 =                        // a thick bar
object { box { UnitBox
               scale < 1 1 2 > }       // longer z axis
         color Green
       }  // end obj Bar 2

/* ********************************************************************* */

#declare Plaque1 =                     // disk with quarters cross
composite {
   object { Medallion  translate < 0.3 0 0 > }
   object { Arch_C scale < 0.1 1 1 > }
   object { Arch_C scale < 0.1 1 1 > rotate < 180 0 0 > }
   object { Bar1                                        }
   object { Bar1                     rotate < 90 0 0 >  }
   object { Bar1                     rotate < 45 0 0 >  }
   object { Bar1                     rotate <-45 0 0 >  }
          }  //end composite Plaque 1

/* ********************************************************************* */

#declare Thing_C =                     // two arches combined
composite{
   object { Arch_B
               scale < 1 1 1 >
               rotate < 90 0 0 >
               translate < 0 5 -7 >
          } //end obj Arch B 1
   object { Arch_B
               scale < 1 1 1 >
               rotate < -90 0 0 >
               translate < 0 5 7 >
          } //end obj Arch B 2
         }  //  end composite Thing C

/* ********************************************************************* */

#declare Thing_D =

composite {
   object { Arch_Plain
            texture { Brown_Agate }
            scale < 4 4 4 >
            rotate < 90 0 0 >
            translate < 0 4 0 >
          }  // Arch Plain B
   object { Arch_Plain
            texture { Brown_Agate }
            scale < 4 4 4 >
            rotate < 90 0 0 >
            rotate < 0 180 0 >
            translate < 0 11 0 >
          }  // Arch Plain B
   object { box { UnitBox
                  scale < 1.5 0.4 1.5 >
                } // end Unit box
            texture { Red_Marble
                      scale < 2 2 2 >
                      rotate < 0 80 0 >
                      reflection 0.3
                    } //end texture
            rotate < 90 0 0 >
            translate < 0 14.5 0 >
            color Red
          } // end obj box
   object { Planet_Blank
            texture { Red_Marble
                      scale < 2 2 2 >
                      rotate < 0 80 0 >
                      reflection 0.3
                    } //end texture
            translate < 0 14.5 1.3 >
            color Red
          } // end Planet

          }  // end composite Thing D

/* ********************************************************************* */

#declare Thing_Plain =                 // 2 arches combined: v.2 11 DEC
composite{
   object { Arch_Plain
               texture { Brown_Agate
                         scale < 0.5 1 0.5 >
                         rotate < 50 0 20 > }
               rotate < 90 0 0 >
               translate < 0 0 -0.6 >
          } //end obj Arch Plain 1
   object { Arch_Plain
               texture { Brown_Agate
                         scale < 0.5 1 0.5 >
                         rotate < 50 0 20 > }
               rotate < -90 0 0 >
               translate < 0 0 0.6 >
          } //end obj Arch Plain 2
         }  //  end composite Thing Plain

/* **************************************************************** */

#declare Grill2 =                      // 4 Things make a wall
composite {
  composite { Thing_Plain }
  composite { Thing_Plain  translate < 0 0 1 > }
  composite { Thing_Plain  translate < 0 0 -1 > }
  composite { Thing_Plain  translate < 0 0 -2 > }
          } // end composite Grill 2

/* ********************************************************************* */

#declare Grill3 =                      // 4 Things make a wall
composite {
  composite { Thing_Plain }
  composite { Thing_Plain  translate < 0 0 1 > }
  composite { Thing_Plain  translate < 0 0 -1 > }
  composite { Thing_Plain  translate < 0 0 -2 > }
  composite { Plaque1                  // insert Plaque into wall
              scale < 0.5 0.5 0.5 >
              translate < -0.25 0 -0.5 > }
          } // end composite Grill 3

/* ********************************************************************* */

#declare GrillBox =                    // 4 Grills make a box v.2 11 DEC
composite {
   composite { Grill2 scale < 1.5 1.5 1.5 > translate < -2.75 1.5  0.6 > } //W
   composite { Grill2 scale < 1.5 1.5 1.5 >
                      rotate < 0 90 0 >     translate <  0.8  1.5  2.7 > } //N
   composite { Grill2 scale < 1.5 1.5 1.5 >
                      rotate < 0 -90 0 >    translate < -0.7  1.5 -3.0 > } //S
   composite { Grill2 scale < 1.5 1.5 1.5 >
                      rotate < 0 180 0 >    translate <  2.9 1.5 -0.9 > } //E
   bounded_by { box {
                  UnitBox  scale < 4.5 3.0 4.5 >
                           translate < 0 0 0 > }
              }  // end bounding
          }  // end composite Grill Box

/* ********************************************************************* */

#declare Platform =                    // something to stand on
object { box { UnitBox
                  texture {
                     Brown_Agate
                     scale < 0.7 0.5 0.7 >
                     ambient 0.2
                     diffuse 0.5
                     reflection 0.2
                          } // end texture
                  scale < 3.8 0.2 3.8 >
             } //end box
       } // end obj Platform

/* ********************************************************************* */

#declare Roof_A =                      // Arch stretched
composite {
   object { Arch_Plain                      // e/w
               texture {
                  Brown_Agate
                  scale < 2 4 2 >
                  ambient 0.2
                  diffuse 0.5
                  reflection 0.2
                       } // end texture
               scale < 18.5 1.6 1.6 > }
   composite { Plaque1 scale < 0.4 0.4 0.4 >
                       translate < -3.8 0.6 0 > }
   composite { Plaque1 scale < 0.4 0.4 0.4 >
                       rotate < 0 180 0 >
                       translate < 3.8 0.6 0 > }
   object { Arch_Plain                      // n/s
               texture {
                  Brown_Agate
                  scale < 1.3 2.0 1.3 >
                  ambient 0.2
                  diffuse 0.5
                  reflection 0.2
                       } // end texture
               scale < 18.5 1.6 1.6 >
               rotate < 0 90 0 > }
   composite { Plaque1 scale < 0.4 0.4 0.4 >
                       rotate < 0 -90 0 >
                       translate < 0.0 0.6 -3.8 > }
   composite { Plaque1 scale < 0.4 0.4 0.4 >
                       rotate < 0 90 0 >
                       translate < 0.0 0.6 3.8 > }
          }  // end composite Roof A

/* ********************************************************************* */

#declare GrillTower =                  // a stack of Boxes, Floors & Roof
composite {
   object    { Platform  translate < 0.1 0.0 0.0 > }
   composite { GrillBox  translate < 0.0 0.0 0.0 > }
   object    { Platform  translate < 0.1 3.0 0.0 > }
   composite { GrillBox  translate < 0.0 3.0 0.0 > }
   object    { Platform  translate < 0.1 6.0 0.0 > }
   composite { Roof_A    translate < 0.0 6.0 0.0 > }
          } //  end composite Grill Tower

/* ********************************************************************* */
/* ********************************************************************* */

//DEFINE  A Column for Entrance
#declare Enter_Column =
composite {
   object { box { UnitBox              // bottom
                     scale < 2.5 0.3 2.5 >
                 } // end box
            texture { Red_Marble
                         scale < 2 2 2 >
                         rotate < 0 80 0 >
                         reflection 0.3
                    } //end texture
            color Red
          } // end obj box
   object { box { UnitBox              // next up
                     scale < 2 0.3 2 >
                 } // end box
            texture { Red_Marble
                         scale < 2 2 2 >
                         rotate < 0 80 0 >
                         reflection 0.3
                    } //end texture
            translate < 0 0.3 0 >
            color Red
          } // end obj box
   object { Pillar_A
            texture { Red_Marble
                         scale < 0.7 0.5 0.7 >
                         turbulence 1.8
                         rotate < 0 30 80 >
                         reflection 0.3
                    } //end texture
            scale < 1.1 2 1.1 >
          } // end obj Pillar

   object { box { UnitBox              // second from top
                     scale < 2 0.3 2 >
                 } // end box
            texture { Red_Marble
                         scale < 2 2 2 >
                         rotate < 0 80 0 >
                         reflection 0.3
                    } //end texture
            translate < 0 9.7 0 >
            color Red
          } // end obj box
   object { box { UnitBox              // top
                     scale < 2.5 0.3 2.5 >
                 } // end box
            texture { Red_Marble
                         scale < 2 2 2 >
                         rotate < 0 80 0 >
                         reflection 0.3
                    } //end texture
            translate < 0 10 0 >
            color Red
          } // end obj box
   bounded_by { box { UnitBox
                      scale < 2.6 10.1 2.6 > }
              } //end bounding
          } // end composite Entrance Column

/* ********************************************************************* */
/* ********************************************************************* */

#declare Brick_B =
    object { box { UnitBox
                     scale < 0.5 1 1 >
                 } // end box
           } // end obj

/* ********************************************************************* */

//DEFINE A layer of Bricks

#declare Course_A =
composite {
    object { Brick_B
             texture { Brown_Agate
                       scale < 0.7 1 0.7 >
                       rotate < -45 0 0 >
                       reflection 0.3
                     } //end texture
             scale < 1.75 2 2 >
             translate < 0 1.5 12.5 >
             color Blue
           } // end obj Brick A
    object { Brick_B
             texture { Brown_Agate
                       scale < 1 1.5 1.1 >
                       reflection 0.3
                     } //end texture
             scale < 1.75 2 2 >
             translate < 0.03 1.5 16.5 >
             color Yellow
           } // end obj Brick A
    object { Brick_B
             texture { Brown_Agate
                       scale < 0.5 1 0.5 >
                       rotate < 45 0 0 >
                       reflection 0.3
                     } //end texture
             scale < 1.75 2 2 >
             translate < 0 1.5 20.5 >
             color Blue
           } // end obj Brick A
    object { Brick_B
             texture { Brown_Agate
                       scale < 1 1.5 1.1 >
                       rotate < 0 0 45 >
                       reflection 0.3
                     } //end texture
             scale < 1.75 2 2 >
             translate < -0.02 1.5 24.5 >
             color Yellow
           } // end obj Brick A
    object { Brick_B
             texture { Brown_Agate
                       scale < 0.5 1 2.5 >
                       rotate < -25 0 0 >
                       reflection 0.3
                     } //end texture
             scale < 1.75 2 2 >
             translate < 0 1.5 28.5 >
             color Blue
           } // end obj Brick A
    object { Brick_B
             texture { Brown_Agate
                       scale < 1.5 4.5 0.5 >
                       rotate < 0 0 85 >
                       reflection 0.3
                     } //end texture
             scale < 1.75 2 2 >
             translate < -0.02 1.5 32.5 >
             color Yellow
           } // end obj Brick A
          } // end composite Course A

/* ********************************************************************* */

//DEFINE A Wall

#declare Wall_B =
composite {
   composite { Course_A }
   composite { Course_A
               translate < 0 6 0 > }
   composite { Course_A
               rotate < 0 0 180 >
               translate < 0 5 0 > }
          } // end composite Wall B

/* ********************************************************************* */

//DEFINE Another Wall                  tall and thin, runs E/W

#declare Wall_C =
object { box {
            UnitBox
            scale < 10 10 1 > }
       } // end object Wall C

/* ********************************************************************* */

#declare PostWall =                    // E/W wall with west end column
composite {
   object { Wall_C  texture { Iris }
                    color Magenta
          } //end object Wall C
   composite { Enter_Column  translate < -10 0 0 > }
          } // end composite Post & Wall

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE Rectangle Pool with Water   *****   from POOL.POV   *****
// ***** revised 4 Dec 96: water really reflects scene        *****

#declare Pool_A =
composite {
  object {                             // the Pool
    difference {
      intersection { Cube
                     scale <26.0 3.0 46.0>
                   } // end Cube outside
      intersection { Cube
                     scale <20.0 4.0 40.0>
                   } // end Cube inside
               } // end difference
      texture {                             // blue&white tiles
        checker colour DarkTurquoise colour White
        scale <2.0 2.0 2.0>
              } // end Tiles texture
      color DarkTurquoise                   //low res. color
         } // end obj Pool

  composite {                          // a cube of water
    object {
       intersection { Cube } // end intersection
       texture {                       // water-like effect
          ripples 0.3
          frequency 60 //
          phase 0.3
          scale <10.0 5.0 10.0>
          reflection 0.8
               } // end water texture
       scale < 20.0 0.5 40.0 >              // must be same as inside cube
       translate < 0.0 1.1 0.0 >            // 1 above floor
                 } // end obj water cube
    object {                           // a subsurface to catch reflections
       plane { < 0 1 0 > 0 }
       texture {
          0.05
          color  red 1.0  green 0.3
          ambient 1.0
          diffuse 0.0
               } // end texture
       scale < 20.0 1.0 40.0 >               // must be same as inside cube
       translate < 0.0 -0.5 0.0 >            // 1/2 below floor
       bounded_by { box
                      { UnitBox
                        scale < 20.2 1.1 40.2 > }
                  } // end bounding
           } // end object Plane
            } // end composite Water Cube

    bounded_by { box {                      // bounding shape
                    UnitBox
                    scale < 23.01 4.5 43.01 > }
               } // end bounding
          }  // end composite Pool A

/* ********************************************************************* */
/* ********************************************************************* */

//DEFINE  Entrance w/ Pillars, Bricks, Decore ...

#declare Entrance =
composite {
   composite { Enter_Column            // north door column
               translate < 0 0.0 10 >
             } // end composite Column
   composite { Enter_Column            // south door column
               translate < 0 0.0 -10 >
             } // end composite Column
   object { Arch_B                     // between columns
            scale < 1.2 0.75 1.1 >
            translate < 0 10 0 >
          } // end object Arch
   composite { Plaque1                 // under arch
               scale < 2 2 2 >
               rotate < 0 180 0 >
               translate < 2 13 0 >
             } // end composite Plaque
   object { Bar2                       // between columns
            texture {
               Red_Marble
               scale < 1 1.5 1 >
               rotate < 45 0 0 >
               ambient 0.2
               diffuse 0.5
               reflection 0.3
                    } // end texture
            scale < 2 0.75 4.5 >
            translate < 0 10.3 0 >
          } // end object Bar
          } // end composite Entrance

/* ********************************************************************* */

//DEFINE An Exit Doorway

#declare Exit =
composite {
   composite { Enter_Column  translate < -50 0  10 > } //west door post
   composite { Enter_Column  translate < -50 0 -10 > } //west door post
   composite { Grill2  scale < 3 5.4 4.5 >
                       translate < -50 4.1 2.3 > } // end Grill Wall
          } // end composite Exit

/* ********************************************************************* */
/* ********************************************************************* */

//DEFINE  an Infantino-esque Tower

#declare Tower_A =
composite {
  object {
    sphere { < 0.0 0.0 0.0 > 1.0 }
    texture { Chrome_Metal
              reflection 0.99 }
    scale < 1 1 1 >
    translate < 0 10 0 >
    color Red
         }  //end obj sphere
  object {
    intersection { Disk_Y }
    texture { Chrome_Metal
              reflection 0.99 }
    scale < 1 2 1 >
    translate < 0 12 0 >
    color Blue
         }  // end object Cylinder
  object {
    sphere { < 0.0 0.0 0.0 > 1.0 }
    texture { Chrome_Metal
              reflection 0.99 }
    scale < 1 1 1 >
    translate < 0 14 0 >
    color Green
         }  //end obj sphere
  object {
    intersection { Disk_Y }
    texture { Chrome_Metal
              reflection 0.99 }
    scale < 0.5 5 0.5 >
    translate < 0.25 5 0.25 >
    color Yellow
         }  // end object Cylinder
          } // end composite Tower A

/* ********************************************************************* */

//DEFINE  Building with rooms & optional statuary

#declare Building_B =
composite {

   composite { Entrance }
   composite { Exit }

   // the four exterior walls
   composite { Wall_B  scale < 1 1 2 >
                       rotate < 0 90 0 >
                       translate < -70 0 35 > }  //north wall
   composite { Wall_B  scale < 1 1 2 >
                       rotate < 0 -90 0 >
                       translate < 20 0 -35 > }  //south wall
   composite { Wall_B }                          //east wall, north part
   composite { Wall_B  translate <   0 0 -45 > } //east wall, south part
   composite { Wall_B  translate < -50 0   0 > } //west wall, north part
   composite { Wall_B  translate < -50 0 -45 > } //west wall, south part

   // four interior walls
   composite { PostWall  rotate < 0 -90 0 >  translate < -35 -0.5  25 > } // N
   composite { PostWall  rotate < 0 -90 0 >  translate < -15 -0.5  25 > } // N
   composite { PostWall  rotate < 0  90 0 >  translate < -15 -0.5 -25 > } // S
   composite { PostWall  rotate < 0  90 0 >  translate < -35 -0.5 -25 > } // S

   // columns at the four corners
   composite { Enter_Column  translate < -50 0  35 > }     //NW corner
   composite { Enter_Column  translate <   0 0  35 > }     //NE corner
   composite { Enter_Column  translate < -50 0 -35 > }     //SW corner
   composite { Enter_Column  translate <   0 0 -35 > }     //SE corner

/*
   // statuary in northern alcoves
   composite { Tower_A    scale < 0.5 0.5 0.5>  translate < -40  0 25 > }
   composite { TestShape  scale < 2 2 2 >       translate < -7.5 2 23 > }
   composite { Thing_Plain  scale < 2 2 2 >
                            rotate < 0 90 0 >
                            translate < -24 2 25 > }

   //statuary in southern alcoves
   composite { GrillTower scale < 1 1 1 > translate < -25 0 -27.5 > }
*/

   bounded_by { box { UnitBox
                      scale < 28.5 20 38 >
                      translate < -25 0 0 > }
              } // end bounding
          } // end composite Building B

/* ********************************************************************* */
/* END OF   CHAMBERS.INC   FILE                               ********** */
/* ********************************************************************* */
