/* ********************************************************************* */
//   Filename: TEST01.POV  :: CHAMBR05.POV                               //
//   Revised Universal Scene Template             Aug-Sept 1996 Ver 2.0  //
//   CHAMBER 3: west alcove,    looking north          Dec 1996 Ver 1.1  //
//   CHAMBER 2: middle alcove,     "      "                              //
//   CHAMBER 1: east alcove,       "      "                              //
//   CHAMBER 4: east alcove, looking south                               //
//   TEST04   : revised Grill Box elements, new chambers.inc             //
//   CHAMBER 5: add a pool to Chambers scene                 FEB 97      //
/* ********************************************************************* */

/* ********************************************************************* */
//                           Global Definitions                          //
/* ********************************************************************* */

#include "basic.inc"                   // Lights Cameras Simple objects
#include "chambers.inc"                // Complex Objects for GrillBox,
                                       // LampPath, Chambers, etc.

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE DEFAULTS

#default { texture { ambient 0.4 } }   // ambient light
max_trace_level 5

/* ********************************** */

//DEFINE SKY  ***** *****

object { sphere { < 0 0 0 > 4000 }
         texture { Blue_Sky            // big puffy white/gray clouds
            scale < 400 200 700 >
            turbulence 0.35
            ambient 0.8
            diffuse 0.8
                 }  //end texture
         color White                   // low resolution display color
       }  //end object Sky

/* ********************************** */

// DEFINE FLOOD LIGHT on TEST OBJECT   *****   at < 0 0 0 >

#declare TestSpot1 =
light_source
    { < -50 50 50 >                    // from here toward...
      color White
      spotlight
      point_at < 1 5 0 >               // center of test obj
      tightness 2.5
      radius 5
      falloff 10
    }  //end of Test Spot 1

/* ********************************** */

// DEFINE FLOOD LIGHT on TEST OBJECT   *****   at < 0 0 0 >

#declare TestSpot2 =
light_source
    { < -70 60 40 >                    // from here toward...
      color White
      spotlight
      point_at < -60 0 70 >            // center of test obj
      tightness 7
      radius 8
      falloff 11
    }  //end of Test Spot 2

/* ********************************** */

// DEFINE FLOOD LIGHT on TEST OBJECT   *****   at < 0 0 0 >

#declare TestSpot3 =
light_source
    { < -10 65 -5 >                    // from here toward...
      color White
      spotlight
      point_at < -7.5 0 23 >            // center of test obj
      tightness 7
      radius 8
      falloff 11
    }  //end of Test Spot

/* ********************************************************************* */

// DECLARE TEST CAMERA  *****  set location and look_at  *****

#declare TestView =
camera {
  location  < 210 50 -50 >
  direction <   0.0   0.0   2.5 >
  up        <   0.0   1.0   0.0 >
  right     <   1.33  0.0   0.0 >
  look_at   < -10 5 0 >
       }  //end of camera Test View

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE SCENE  *****  TEST OF ASSORTED STANDARDIZED ELEMENTS    *****

/* ********************************** */
// LIGHTS!                        ***** DEFINE LIGHT SOURCES

//                                ***** global lighting
object { light_source { FloodRear } }  // high rear flood light
//object { light_source { FloodSouth } } // low front flood light
object { light_source { FloodSE1 } }   // high flood light
//object { light_source { FloodSW1 } }   // high flood light
//object { light_source { FloodSE2 } }   // high flood light
//object { light_source { FloodNE1 } }   // high flood light
//object { light_source { FloodNW1 } }
//object { light_source { FloodSW } }

//                                ***** Test Locations
object { light_source { TestSpot1 } }  // on < 0 0 0 > Test Object
//object { light_source { TestSpot2 } }  // on < 0 0 0 > Test Object
//object { light_source { TestSpot3 } }  // on < 0 0 0 > Test Object


/* ********************************** */
// CAMERA!                        ***** POSITION CAMERA

camera { TestView }                    // Variable with each view
//camera { OverHigh }                    // < 0 650 -1 >
//camera { OverMed }                     // < 0 300 -1 >
//camera { OverLow }                     // < 0 100 -1 >

//camera { South1 }                      // <   0 20 -50 >
//camera { West1 }                       // < -50 20   0 >
//camera { North1 }                      // <   0 20  50 >
//camera { East1 }                       // <  50 20   0 >

//camera { SouthWest1 }                  // < -25 20 -25 >
//camera { SouthWest2 }                  // < -50 20 -50 >
//camera { NorthWest1 }                  // < -25 20  25 >
//camera { NorthWest2 }                  // < -50 20  50 >

//camera { SouthEast1 }                  // < 25 20 -25 >
//camera { SouthEast2 }                  // < 50 20 -50 >
//camera { NorthEast1 }                  // < 25 20  25 >
//camera { NorthEast2 }                  // < 50 20  50 >


/* ********************************** */
// ACTION!                        ***** DESCRIBE ELEMENTS IN SCENE

//object { Test_Floor }

object { Floor13_B }

//composite { Grid_Zero }


/* ********************************************************************* */
/*  *****                   TEST  THIS  OBJECT:                    ***** */
/* ********************************************************************* */

//DEFINE Building with interior walls and Objects in the alcoves
//       with pool, trees, shrubs, paths

composite { Building_B  scale < 2 2 2 > }      //revised
composite { Pool_A  scale < 0.75 1 0.75 >  translate < 22 0 0.3 > }
object    { Road2   scale < 1.25 1 1 >
                    rotate < 0 90 0 > translate < 0 0.2 0 > }
object    { Hedge_B scale < 3.5 2 1.1 >  translate < 22.5 0  36 > }
object    { Hedge_B scale < 3.5 2 1.1 >  translate < 22.5 0 -36 > }
composite { Row_Of_Trees scale < 1.1 1.1 1.1 >
                         rotate < 0 90 0 > translate < 5 0  41 > }
composite { Row_Of_Trees scale < 1.1 1.1 1.1 >
                         rotate < 0 90 0 > translate < 5 0 -41 > }
composite { Piri_Glass_B scale < 2.8 2.8 2.8 > translate < -50 1 0 > }

/* ********************************************************************* */
/* END OF  CHAMBER 5  FILE                       *********************** */
/* ********************************************************************* */
