/* ********************************************************************* */
//   Filename: TEST.POV                                                  //
//   Michael Brendan Hurley for ShadowDancer Enterprizes, LTD.           //
//   Revised Universal Scene Template           Aug 96 - Mar 97 Ver 2.0  //
//   Annotated for use as a tutorial .POV file                           //
/* ********************************************************************* */
//
// PROCEDURE:
// 1. Copy this file to create another POV file with a different name;
//    for example: COPY TEST.POV MYFIRST.POV.
// 2. Use your favorite ASCI editor to edit MYFIRST.POV to
//    a. remove all these comments and directions, and
//    b. to insert your own, or copied, scripts of scene descriptions
//       into the appropriate places in the script below.
// 3. Save your new .POV file and run it according to the directions
//    in the program manual.
// 4. Test, edit, recopy, resave your .POV file with new names as your
//    scene evolves.
//
// This template uses a set of definitions I wrote to facilitate the
// creation of new objects and scenes.  These definitions are in the file
// BASIC.INC and are linked to this .POV file by the #include notation
// below.  Feel free and add to them or modify them to suit your work.
// The definitions include:
// 1. a set of standardized camera and spot light locations focused on the
//    center of the ray-tracing world < 0 0 0 >;
// 2. a small collection of elementary objects (walls, floors, spheres,
//    boxes, etc.) to which you can add textures and transformations
//    to build your own scenes; and
// 3. a set of composite objects I wrote called Grid_Zero, Grid_Plus, and
//    Grid_Up. It produces a grid of unit spheres centered on < 0 0 0 > on
//    the "floor" of the world.  I find this grid very useful in locating
//    objects in complex landscape scenes.  In Grid_Zero the markers on the
//    main x and z axis (red) are 10 units apart; other markers show the
//    50 unit (yellow) and 100 unit (green) gradations.  Grid_Plus has
//    markers in the +x +z quadrant every 20 units.  Grid_Up features 10
//    unit markers in the + and - y axis for vertical positions.
//
/* ********************************************************************* */
/* ********************************************************************* */
//                           Global Definitions                          //
// To link with .INClude files of definitions for the whole scene        //
/* ********************************************************************* */

#include "basic.inc"                   // Lights Cameras Simple objects
#include "temple.inc"                  // Textures, Complex Objects

// add your own Include files here

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE DEFAULTS

#default { texture { ambient 0.3 } }   // ambient light

/* ********************************************************************* */

// DEFINE SKY  ***** *****

object { sphere { < 0 0 0 > 6000 }
         texture { Blue_Sky            // big puffy white/gray clouds
            scale < 400 200 700 >
            turbulence 0.25
            ambient 0.7
            diffuse 0.7
                 }  //end texture
         color White                   // low resolution display color
       }  //end object Sky

/* ********************************************************************* */

// DEFINE SPOT LIGHT on Test Object at < 0 0 0 >

#declare TestSpot =
light_source {
   < 15 35 -60 >                       // from south east
   color White
   spotlight
   point_at < 0 5 0 >                  // Test object
   tightness 25
   radius 20
   falloff 50
             }  // end of TestSpot

/* ********************************************************************* */

// DECLARE TEST CAMERA  *****  set location and look_at  *****

#declare TestView =
camera {
  location  < -25.0  10.0  -25.0 >     // near SW of < 0 0 0 >
  direction <   0.0   0.0    2.0 >
  up        <   0.0   1.0    0.0 >
  right     <   1.33  0.0    0.0 >
  look_at   <   0.0   5.0    0.0 >     // world center 5.0 above floor
       }  //end of camera Test View

/* ********************************************************************* */
//                           Texture Definitions                         //
//         To describe user made textures or modify stock textures       //
/* ********************************************************************* */

// Insert your texture definitions here

/* ********************************************************************* */
//                            Object Definitions                         //
//         To describe user made objects or modify stock objects         //
/* ********************************************************************* */

// Insert your object definitions here

/* ********************************************************************* */
// DEFINE SCENE  *****   TEST OF ASSORTED STANDARDIZED ELEMENTS    ***** //
/* ********************************************************************* */

// LIGHTS!                        ***** DEFINE LIGHT SOURCES

//                                ***** global lighting
object { light_source { FloodRear } }  // high rear flood light
object { light_source { FloodSouth } } // low front flood light
//object { light_source { FloodSE } }    // high checker flood light
//object { light_source { FloodSW } }    // high checker flood light

//                                ***** spots on < 0 0 0 >
//object { light_source { SpotRight1 } } // +x +y +z spot light
//object { light_source { SpotLeft1 } }  // -x +y -z spot light
//object { light_source { SpotRight2 } } // +x -y -z spot light
//object { light_source { SpotLeft2 } }  // -x -y -z spot light

//                                ***** Test Locations
object { light_source { TestSpot } }   // on < 0 0 0 > Test Object
//object { light_source { TestSpot2 } }  //
//object { light_source { TestSpot3 } }  //


// CAMERA!                        ***** POSITION CAMERA

camera { TestView }                    // Variable with each view
//camera { OverHigh }                    // < 0 650 -1 >
//camera { OverMed }                     // < 0 300 -1 >
//camera { OverLow }                     // < 0 100 -1 >

//camera { South1 }                      // <   0 20 -50 >
//camera { West1 }                       // < -50 20   0 >
//camera { North1 }                      // <   0 20  50 >
//camera { East1 }                       // <  50 20   0 >

//camera { SouthWest1 }                  // < -25 20 -25 >
//camera { SouthWest2 }                  // < -50 20 -50 >
//camera { NorthWest1 }                  // < -25 20  25 >
//camera { NorthWest2 }                  // < -50 20  50 >

//camera { SouthEast1 }                  // < 25 20 -25 >
//camera { SouthEast2 }                  // < 50 20 -50 >
//camera { NorthEast1 }                  // < 25 20  25 >
//camera { NorthEast2 }                  // < 50 20  50 >


// ACTION!                        ***** DESCRIBE ELEMENTS IN SCENE

object { Floor13_B }

composite { Grid_Zero
            translate < 0 0 0> }

//composite { Grid_Plus
//            translate < 0 0 0> }

//composite { Grid_Up
//            translate < 0 0 0> }

/* ********************************************************************* */
/*  *****                   TEST  THIS  OBJECT:                    ***** */
/* ********************************************************************* */

composite { TestShape                  //at center of world & view
            scale < 2 2 2 >
            translate < 0 1 0 >
          } //end composite Test

/* ********************************************************************* */
/* END OF   TEST Template   FILE              ************************** */
/* ********************************************************************* */
