/* ********************************************************************* */
//   Filename: TEST10.POV                                                //
//   Michael Brendan Hurley for ShadowDancer Enterprizes, LTD.           //
//   Revised Universal Scene Template             Aug96-Oct 97  Ver 2.1  //
/* ********************************************************************* */

/* ********************************************************************* */
//                           Global Definitions                          //
/* ********************************************************************* */

#include "basic.inc"                   // Lights Cameras Simple objects
#include "rooms.inc"                   // Textures, Complex Objects

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE DEFAULTS

#default { texture { ambient 0.7 } }   // ambient light
max_trace_level 4

/* ********************************************************************* */

// DEFINE SKY  ***** *****

object { sphere { < 0 0 0 > 50000 }
         texture { Blue_Tex
            ambient 0.7
            diffuse 0.7
                 }  //end texture
         color White                   // low resolution display color
       }  //end object Sky

/* ********************************************************************* */

// DEFINE SPOT LIGHT on Test Object at < 0 0 0 >

#declare TestSpot =
light_source {
   < 50 50 -60 >                       // from south east
   color White
   spotlight
   point_at < 0 5 0 >                  // Test object
   tightness 25
   radius 20
   falloff 50
             }  // end of TestSpot

/* ********************************************************************* */

// DECLARE TEST CAMERA  *****  set location and look_at  *****

#declare TestView =
camera {
  direction <   0.0   0.0    1.5 >
  location  < -30.0  25.0  -30.0 >     // near SW of < 0 0 0 >
  look_at   <   0.0   5.0    0.0 >     // world center 5.0 above floor
       }  //end of camera Test View

/* ********************************************************************* */
//                           Texture Definitions                         //
//         To describe user made textures or modify stock textures       //
/* ********************************************************************* */

/* ********************************************************************* */
//                            Object Definitions                         //
//         To describe user made objects or modify stock objects         //
/* ********************************************************************* */

/* ********************************************************************* */
// DEFINE SCENE  *****   TEST OF ASSORTED STANDARDIZED ELEMENTS    ***** //
/* ********************************************************************* */

/* ********************************************************************* */
// LIGHTS!                        ***** DEFINE LIGHT SOURCES

//                                ***** global lighting
object { light_source { FloodRear } }  // high rear flood light
object { light_source { FloodSouth } } // low front flood light
//object { light_source { FloodSE1 } }    // high checker flood light
//object { light_source { FloodSW1 } }    // high checker flood light
//composite { Flood_Bank1 }              // pseudo sun  -300
//composite { Flood_Bank2 }              // pseudo sun  -700

//                                ***** spots on < 0 0 0 >
//object { light_source { SpotRight1 } } // +x +y +z spot light
//object { light_source { SpotLeft1 } }  // -x +y -z spot light
//object { light_source { SpotRight2 } } // +x -y -z spot light
//object { light_source { SpotLeft2 } }  // -x -y -z spot light

//                                ***** Test Locations
//object { light_source { TestSpot } }   // on < 0 0 0 > Test Object
//object { light_source { TestSpot2 } }  //
//object { light_source { TestSpot3 } }  //

/* ********************************************************************* */
// CAMERA!                        ***** POSITION CAMERA

camera { TestView }                    // Variable with each view
//camera { OverHigh }                    // < 0 650 -1 >
//camera { OverMed }                     // < 0 300 -1 >
//camera { OverLow }                     // < 0 100 -1 >

//camera { South1 }                      // <   0 20 -50 >
//camera { West1 }                       // < -50 20   0 >
//camera { North1 }                      // <   0 20  50 >
//camera { East1 }                       // <  50 20   0 >

//camera { SouthWest1 }                  // < -25 20 -25 >
//camera { SouthWest2 }                  // < -50 20 -50 >
//camera { NorthWest1 }                  // < -25 20  25 >
//camera { NorthWest2 }                  // < -50 20  50 >

//camera { SouthEast1 }                  // < 25 20 -25 >
//camera { SouthEast2 }                  // < 50 20 -50 >
//camera { NorthEast1 }                  // < 25 20  25 >
//camera { NorthEast2 }                  // < 50 20  50 >

/* ********************************************************************* */
// ACTION!                        ***** DESCRIBE ELEMENTS IN SCENE

object { Floor13_B }

composite { Grid_Zero
            translate < 0 0 0> }
/*
composite { Grid_Plus
            translate < 0 0 0> }

composite { Grid_Up
            translate < 0 0 0> }

composite { Push_Pin  translate <  20 0 15 > } //markers
composite { Push_Pin  translate <  20 0 65 > }

object { Rod_X  translate < 0 0 0 > }  //tubular markers
object { Rod_Y  translate < 0 0 0 > }
object { Rod_Z  translate < 0 0 0 > }
*/

/* ********************************************************************* */
/*  *****                   TEST  THIS  OBJECT:                    ***** */
/* ********************************************************************* */


composite { TestShape                  //at center of world & view
            scale < 3 3 3 >
            translate < 0 1 0 >
          } //end composite Test


/* ********************************************************************* */
/* END OF   TEST Template   FILE              ************************** */
/* ********************************************************************* */
