/* ********************************************************************* */
//   Filename: TEST19.POV & .GIF                      3 Oct 97 Ver 1.0   //
//   Michael Brendan Hurley for ShadowDancer Enterprizes, LTD.           //
//   Three sample torii, variants D, E & F                               //
/* ********************************************************************* */

/* ********************************************************************* */
//                           Global Definitions                          //
/* ********************************************************************* */

#include "basic.inc"                   // Lights Cameras Simple objects
#include "tex.inc"                     //edited from Textures.INC
#include "odd_ends.inc"                //assorted weird shapes

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE DEFAULTS

#default { texture { ambient 0.7 } }   // ambient light
max_trace_level 4

/* ********************************** */

// DEFINE SKY  ***** *****

object { sphere { < 0 0 0 > 20000 }
         texture { MidBlue_Tex
            ambient 0.7
            diffuse 0.7
                 }  //end texture
         color LightBlue
       }  //end object Sky

/* ********************************************************************* */

// DECLARE TEST CAMERA  *****  set location and look_at  *****

#declare TestView =
camera {
  direction <  0.0   0.0    3.5 >       // three torii view
  location  < 75.0  75.0  -75.0 >       // SE of < 0 0 0 >
  look_at   <  0.0  20.0    0.0 >       // view center
       }  //end of camera Test View

/* ********************************************************************* */

/* Torus having major radius sqrt(40), minor radius sqrt(12) */

#declare Torus_OneD =                  //A=wtorus altered
object {
   quartic {                           // WTORUS.POV:test19.gif
      < 1.0   0.0    0.0    0.0     2.0   0.0   0.0   2.0   0.0 -116.0
        0.0   0.0    0.0    0.0     0.0   0.0   0.0   0.0   0.0     0.0
        1.0   0.0    0.0    2.0     0.0  80.0   0.0   0.0   0.0     0.0
        1.0   0.0 -116.0    0.0  1600.0 >
           } //end wtorus version torus
             //#09: sweeze(-)/expand(+) center of ring z-axis
             //#32: sweeze(-)/expand(+) center of ring x-axis
             //#34: (-)fat ring/(+)slim ring
   bounded_by { sphere { <0 0 0> 10 } } //end bounding
   texture {
      Blood_Marble
      ambient 0.2
      diffuse 0.6 } //end texture
   color Red
       } // end object Torus One D

/* ********************************************************************* */

#declare Torus_OneE =                  //A=wtorus altered
object {
   quartic {                           // WTORUS.POV:test19.gif
      < 1.0   0.0    0.0    0.0     1.0   0.0   0.0   1.0   0.0  -100.0
        0.0   0.0    0.0    0.0     0.0   0.0   0.0   0.0   0.0     0.0
        1.0   0.0    0.0    2.0     0.0  80.0   0.0   0.0   0.0     0.0
        1.0   0.0  -90.0    0.0  700.0 >
           } //end wtorus version torus
             //#32: sweeze(-)/expand(+) center of ring
             //#34: (-)fat ring/(+)slim ring
   bounded_by { sphere { <0 0 0> 10 } } //end bounding
   texture {
      Blood_Marble
      ambient 0.2
      diffuse 0.6 } //end texture
   color Red
       } // end object Torus One E

/* ********************************************************************* */

#declare Torus_OneF =                  //A=wtorus altered
object {
   quartic {                           // WTORUS.POV:test19.gif
      < 1.0   0.0    0.0    0.0     1.0   0.0   0.0   1.0   0.0   -75.0
        0.0   0.0    0.0    0.0     0.0   0.0   0.0   0.0   0.0     0.0
        1.0   0.0    0.0    1.0     0.0  80.0   0.0   0.0   0.0     0.0
        1.0   0.0   25.0    0.0    25.0 >
           } //end wtorus version torus
             //#32: sweeze(-)/expand(+) center of ring
             //#34: (-)fat ring/(+)slim ring
   bounded_by { sphere { <0 0 0> 10 } } //end bounding
   texture {
      Blood_Marble
      ambient 0.2
      diffuse 0.6 } //end texture
   color Red
       } // end object Torus One F

/* ********************************************************************* */
// DEFINE SCENE  *****   TEST OF ASSORTED STANDARDIZED ELEMENTS    ***** //
/* ********************************************************************* */

/* ********************************************************************* */
// LIGHTS!                        ***** DEFINE LIGHT SOURCES
/* ********************************************************************* */

//                                ***** global lighting
//object { light_source { FloodRear } }  // high rear flood light
//object { light_source { FloodSouth } } // low front flood light
//object { light_source { FloodSW2 } }    // high flood light
//object { light_source { FloodSW1 } }    // high flood light
//composite { Flood_Bank1 }              // pseudo sun  -300
composite { Flood_Bank2 translate < -500 500 -500 >}  // pseudo sun -700 + -500

/* ********************************************************************* */
// CAMERA!                        ***** POSITION CAMERA
/* ********************************************************************* */

camera { TestView }                    // Variable with each view

/* ********************************************************************* */
// ACTION!                        ***** DESCRIBE ELEMENTS IN SCENE
/* ********************************************************************* */

//object { Test_Floor  texture { Gray75_Tex } }  //  end Test Floor

/* ********************************************************************* */
/*  *****                   TEST  THIS  OBJECT:                    ***** */
/* ********************************************************************* */

// basic wtorus definition edited:
object { Torus_OneD rotate <  0 0  0 > translate <   0  5 0 > } //flat
object { Torus_OneE rotate <  0 0  0 > translate <   0 20 0 > } //flat
object { Torus_OneF rotate <  0 0  0 > translate <   0 35 0 > } //flat

/*
//  basic torus transformations:
object { Torus_One rotate <  0 0  0 > translate <   0  5  0 > } //flat
object { Torus_One rotate < 90 0  0 > translate <   0 10 10 > } //faces N/S
object { Torus_One rotate <  0 0 90 > translate < -10 10  0 > } //faces E/W
*/

/* ********************************************************************* */

/*      STORAGE   *****

object { Test_Floor texture { Chex_Tex//Gray75_Tex//Grass } }
composite { Grid_Zero  translate < 0 0 0> }
composite { Grid_Plus  translate < 0 0 0> }
composite { Grid_Up    translate < 0 0 0> }
composite { Push_Pin  translate <  20 0 15 > } //markers
composite { Push_Pin  translate <  20 0 65 > }

*/     //END STORAGE                                                 *****

/* ********************************************************************* */
/* END OF   TEST19 Template   FILE              ************************ */
/* ********************************************************************* */
